@@ -1,4 +1,4 @@
-/* Copyright (c) 2000-2008 Wolfgang Hoermann and Josef Leydold */
+/* Copyright (c) 2000-2009 Wolfgang Hoermann and Josef Leydold */
 /* Department of Statistics and Mathematics, WU Wien, Austria  */
 
 #include <unur_source.h>
@@ -15,6 +15,7 @@ static const char distr_name[] = "pareto";
 static double _unur_pdf_pareto( double x, const UNUR_DISTR *distr );
 static double _unur_dpdf_pareto( double x, const UNUR_DISTR *distr );
 static double _unur_cdf_pareto( double x, const UNUR_DISTR *distr );
+static double _unur_invcdf_pareto( double u, const UNUR_DISTR *distr );
 static int _unur_upd_mode_pareto( UNUR_DISTR *distr );
 static int _unur_upd_area_pareto( UNUR_DISTR *distr );
 static int _unur_set_params_pareto( UNUR_DISTR *distr, const double *params, int n_params );
@@ -38,6 +39,15 @@ _unur_cdf_pareto( double x, const UNUR_DISTR *distr )
   register const double *params = DISTR.params;
   return ( (x<k) ? 0. : (1. - pow(k/x,a)) );
 } 
+double
+_unur_invcdf_pareto( double U, const UNUR_DISTR *distr )
+{ 
+  register const double *params = DISTR.params;
+  double X;
+  X = pow(1-U, -1/a);
+  X *= k;
+  return X;
+} 
 int
 _unur_upd_mode_pareto( UNUR_DISTR *distr )
 {
@@ -92,10 +102,10 @@ unur_distr_pareto( const double *params, int n_params )
   distr = unur_distr_cont_new();
   distr->id = UNUR_DISTR_PARETO;
   distr->name = distr_name;
-  DISTR.init = _unur_stdgen_pareto_init;
-  DISTR.pdf  = _unur_pdf_pareto;  
-  DISTR.dpdf = _unur_dpdf_pareto; 
-  DISTR.cdf  = _unur_cdf_pareto;  
+  DISTR.pdf    = _unur_pdf_pareto;    
+  DISTR.dpdf   = _unur_dpdf_pareto;   
+  DISTR.cdf    = _unur_cdf_pareto;    
+  DISTR.invcdf = _unur_invcdf_pareto; 
   distr->set = ( UNUR_DISTR_SET_DOMAIN |
 		 UNUR_DISTR_SET_STDDOMAIN |
   		 UNUR_DISTR_SET_MODE   |
