@@ -1,9 +1,9 @@
-/* Copyright (c) 2000-2008 Wolfgang Hoermann and Josef Leydold */
+/* Copyright (c) 2000-2009 Wolfgang Hoermann and Josef Leydold */
 /* Department of Statistics and Mathematics, WU Wien, Austria  */
 
 extern int unur_errno;
 int unur_get_errno ( void );
 void unur_reset_errno ( void );
-const char *unur_get_strerror ( const int unur_errno );
+const char *unur_get_strerror ( const int errnocode );
 UNUR_ERROR_HANDLER *unur_set_error_handler( UNUR_ERROR_HANDLER *new_handler );
 UNUR_ERROR_HANDLER *unur_set_error_handler_off( void );
