@@ -51,3 +51,7 @@ for (i in 1:n.rep.params) {
 unur.test.statistic()
 
 ## -- End -------------------------------------------------------------------
+
+detach("package:Runuran",unload = TRUE)
+
+## --------------------------------------------------------------------------
